@@ -89,7 +89,7 @@ class Risk(NetBoxModel):
         return self.name
 
     def get_absolute_url(self):
-        return reverse('plugins:users_and_computers:risk', args=[self.pk])
+        return reverse('plugins:users_and_computers:aduser', args=[self.pk])
 
 
 class RiskRelation(NetBoxModel):
